##
##  gc.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2023 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_opkg   8.2.4
%define       V_dist   8.2.4
%define       V_subdir 8.2.4

#   package information
Name:         gc
Summary:      Conservative Garbage Collector Library for C/C++
URL:          http://www.hboehm.info/gc/
Vendor:       Hans Boehm et al.
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        BASE
Group:        Libraries
License:      MIT-style
Version:      %{V_opkg}
Release:      20231015

#   package version
%option       with_threads no

#   list of sources
Source0:      http://www.hboehm.info/gc/gc_source/gc-%{V_dist}.tar.gz

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, gcc, pkgconfig
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  libatomicops
PreReq:       libatomicops

%description
    The Boehm-Demers-Weiser conservative garbage collector can be used
    as a garbage collecting replacement for C malloc or C++ new. It is
    also used by a number of programming language implementations that
    use C as intermediate code.

%track
    prog gc = {
        version   = %{V_dist}
        url       = http://www.hboehm.info/gc/gc_source/
        regex     = gc-(\d+\.\d+(?:\.\d+)*)\.tar\.gz
    }

%prep
    %setup -q -n gc-%{V_subdir}

%build
%if "%{with_threads}" == "yes"
    CC="%{l_cc}" \
    CXX="%{l_cxx}" \
    CFLAGS="%{l_cflags -O}" \
    CXXFLAGS="%{l_cxxflags -O}" \
    LDFLAGS="%{l_ldflags}" \
    ./configure \
        --prefix=%{l_prefix} \
        --enable-threads=posix \
        --enable-cplusplus \
        --disable-shared
    %{l_make} %{l_mflags -O}
    mv .libs/libgc.a libgcthread.a
    %{l_make} %{l_mflags} distclean
%endif
    CC="%{l_cc}" \
    CXX="%{l_cxx}" \
    CFLAGS="%{l_cflags -O}" \
    CXXFLAGS="%{l_cxxflags -O}" \
    LDFLAGS="%{l_ldflags}" \
    ./configure \
        --prefix=%{l_prefix} \
        --mandir=%{l_prefix}/man \
        --disable-threads \
        --enable-cplusplus \
        --disable-shared
    %{l_make} %{l_mflags -O}

%install
    %{l_make} %{l_mflags} install \
        AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT"
    rm -f $RPM_BUILD_ROOT%{l_prefix}/lib/*.la
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/share/doc
%if "%{with_threads}" == "yes"
    %{l_shtool} install -c -m 644 \
        libgcthread.a $RPM_BUILD_ROOT%{l_prefix}/lib/
%endif
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%doc %{l_prefix}/share/gc/*'

%files -f files

%clean

